@@ -8,7 +8,7 @@
 
 "MCMCoprobit" <-
   function(formula, data = parent.frame(), burnin = 1000, mcmc = 10000,
-           thin = 1, tune = NA, verbose = FALSE, seed = NA, beta.start = NA,
+           thin = 1, tune = NA, verbose = 0, seed = NA, beta.start = NA,
            b0 = 0, B0 = 0, ...) {
 
 
@@ -110,12 +110,12 @@
     gamma[3:ncat] <- (polr.out$zeta[2:(ncat-1)] - polr.out$zeta[1])*.588
     gamma[ncat+1] <- 300
     
-    ## posterior density sample
+    ## posterior sample
     sample <- matrix(data=0, mcmc/thin, K + ncat + 1)
 
     ## call C++ code to draw sample
     auto.Scythe.call(output.object="posterior", cc.fun.name="MCMCoprobit",
-                     sample=sample, Y=as.integer(Y), X=X, 
+                     sample.nonconst=sample, Y=as.integer(Y), X=X, 
                      burnin=as.integer(burnin),
                      mcmc=as.integer(mcmc), thin=as.integer(thin),
                      tune=as.double(tune), lecuyer=as.integer(lecuyer),
@@ -128,10 +128,10 @@
     sample <- matrix(posterior$sampledata, posterior$samplerow,
                      posterior$samplecol, byrow=TRUE)
     sample <- sample[,c(1:K, (K+3):(K+ncat))]
-    output <- mcmc(data=sample, start=1, end=mcmc, thin=thin)
+    output <- mcmc(data=sample, start=burnin+1, end=burnin+mcmc, thin=thin)
     xnames <- c(X.names, paste("gamma", 2:(ncat-1), sep=""))
     varnames(output) <- xnames
-    attr(output, "title") <- "MCMCoprobit Posterior Density Sample"
+    attr(output, "title") <- "MCMCoprobit Posterior Sample"
         
     return(output)
   }
